==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/WebDropdownDescriptionModule.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, markType } from "./type";
import { WebDropdownItemDescriptionModule } from "./WebDropdownItemDescriptionModule";
import { WebDropdownHeaderDescriptionModule } from "./WebDropdownHeaderDescriptionModule";
import { WebDropdownGroupDescriptionModule } from "./WebDropdownGroupDescriptionModule";
import { WebDropdownDescriptionMetadata } from "./WebDropdownDescriptionMetadata";
/**
 * @hidden
 */
var WebDropdownDescriptionModule = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebDropdownDescriptionModule, _super);
    function WebDropdownDescriptionModule() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebDropdownDescriptionModule.register = function (a) {
        WebDropdownItemDescriptionModule.register(a);
        WebDropdownHeaderDescriptionModule.register(a);
        WebDropdownGroupDescriptionModule.register(a);
        WebDropdownDescriptionMetadata.d(a);
    };
    WebDropdownDescriptionModule.$t = markType(WebDropdownDescriptionModule, 'WebDropdownDescriptionModule');
    return WebDropdownDescriptionModule;
}(Base));
export { WebDropdownDescriptionModule };

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm5/lib/WebDropdownDescriptionModule.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, markType } from "./type";
import { WebBaseComboBoxLikeDescriptionModule } from "./WebBaseComboBoxLikeDescriptionModule";
import { WebDropdownItemDescriptionModule } from "./WebDropdownItemDescriptionModule";
import { WebDropdownHeaderDescriptionModule } from "./WebDropdownHeaderDescriptionModule";
import { WebDropdownGroupDescriptionModule } from "./WebDropdownGroupDescriptionModule";
import { WebDropdownItemComponentEventArgsDescriptionMetadata } from "./WebDropdownItemComponentEventArgsDescriptionMetadata";
import { WebDropdownDescriptionMetadata } from "./WebDropdownDescriptionMetadata";
/**
 * @hidden
 */
var WebDropdownDescriptionModule = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebDropdownDescriptionModule, _super);
    function WebDropdownDescriptionModule() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebDropdownDescriptionModule.register = function (a) {
        WebBaseComboBoxLikeDescriptionModule.register(a);
        WebDropdownItemDescriptionModule.register(a);
        WebDropdownHeaderDescriptionModule.register(a);
        WebDropdownGroupDescriptionModule.register(a);
        WebDropdownItemComponentEventArgsDescriptionMetadata.d(a);
        WebDropdownDescriptionMetadata.d(a);
    };
    WebDropdownDescriptionModule.$t = markType(WebDropdownDescriptionModule, 'WebDropdownDescriptionModule');
    return WebDropdownDescriptionModule;
}(Base));
export { WebDropdownDescriptionModule };
